import React from 'react';
import { ICrossButtonProps } from 'react-native-cross-components';
import { IEmailProps, ICodeProps, ITestIDProps } from '../../types';
/**
 * Props for the {@link ConfirmForm} component.
 *
 * Required properties: {@link onConfirmPress}.
 *
 * Allows you to customize {@link ICodeProps} and {@link IEmailProps}.
 */
export interface IConfirmFormProps extends IEmailProps, ICodeProps, ITestIDProps {
    /**
     * Occurs when the user press "confirm" button. Required.
     */
    onConfirmPress: () => void;
    /**
     * Optional props for the register button. Typically used to change the `title` prop.
     *
     * Read more:
     * https://crossplatformsweden.github.io/react-native-components/interfaces/_components_buttons_crossbutton_.icrossbuttonprops.html
     *
     * @example
     *  <ConfirmForm confirmButtonProps={{title: 'Enlist'}}>
     *     <Text>Custom layouts here</Text>
     *  </ConfirmForm>
     */
    confirmButtonProps?: ICrossButtonProps | undefined;
}
/**
 * Allows the user to ender credentials and passes them back through prop events.
 *
 * Props are {@link IConfirmFormProps}
 *
 * @example
 *  <ConfirmForm
 *      onConfirmPress={(code) => console.log('Confirmed', code)}
 *      confirmButtonProps={{title: 'Enlist'}}
 *      codeInputProps={{label: 'WouldntYouLikeToKnow'}}>
 *     <Text>Custom layouts here</Text>
 *  </ConfirmForm>
 */
export declare class ConfirmForm extends React.Component<IConfirmFormProps> {
    render(): JSX.Element;
}
export default ConfirmForm;
//# sourceMappingURL=ConfirmForm.d.ts.map