import React from 'react';
import { ICrossButtonProps } from 'react-native-cross-components';
import { IEmailProps, ITestIDProps } from '../../types';
/**
 * Properties for {@link ForgotForm} component. Required prop is {@link onSubmit}.
 */
export interface IForgotFormProps extends IEmailProps, ITestIDProps {
    /**
     * Occurs when the user clicks "reset password" button. Required.
     */
    onSubmit: () => void;
    /**
     * Optional props for the submit button. Typically used to change the `title` prop.
     *
     * Read more:
     * https://crossplatformsweden.github.io/react-native-components/interfaces/_components_buttons_crossbutton_.icrossbuttonprops.html
     *
     * @example
     *  <ForgotForm buttonProps={{title: 'Warp'}}>
     *     <Text>Custom layouts here</Text>
     *  </ForgotForm>
     */
    buttonProps?: ICrossButtonProps | undefined;
    testID?: string | undefined;
}
/**
 * Allows the user to input e-mail and press "Resend password" button.
 *
 * Expects {@link IForgotFormProps.onSubmit} callback event.
 *
 * Properties are {@link IForgotFormProps}.
 */
export declare class ForgotForm extends React.Component<IForgotFormProps> {
    render(): JSX.Element;
}
export default ForgotForm;
//# sourceMappingURL=ForgotForm.d.ts.map