import React from 'react';
import { ICrossButtonProps } from 'react-native-cross-components';
import { IEmailProps, IPasswordProps, ICodeProps, ITestIDProps } from '../../types';
/**
 * Props for the {@link PasswordForm} component.
 *
 * Required properties: {@link onSavePress}.
 *
 * Allows you to customize {@link ICodeProps}, {@link IEmailProps} and {@link IPasswordProps}.
 */
export interface IPasswordFormProps extends IEmailProps, IPasswordProps, ICodeProps, ITestIDProps {
    /**
     * Occurs when the user press "save" button. Required.
     */
    onSavePress: () => void;
    /**
     * Optional props for the register button. Typically used to change the `title` prop.
     *
     * Read more:
     * https://crossplatformsweden.github.io/react-native-components/interfaces/_components_buttons_crossbutton_.icrossbuttonprops.html
     *
     * @example
     *  <PasswordForm confirmButtonProps={{title: 'Enlist'}}>
     *     <Text>Custom layouts here</Text>
     *  </PasswordForm>
     */
    saveButtonProps?: ICrossButtonProps | undefined;
}
/**
 * Allows the user to ender credentials and passes them back through prop events.
 *
 * Props are {@link IPasswordFormProps}
 *
 * @example
 *  <PasswordForm
 *      onSavePress={(code) => console.log('Confirmed', code)}
 *      saveButtonProps={{title: 'Enlist'}}
 *      codeInputProps={{label: 'WouldntYouLikeToKnow'}}>
 *     <Text>Custom layouts here</Text>
 *  </PasswordForm>
 */
export declare class PasswordForm extends React.Component<IPasswordFormProps> {
    render(): JSX.Element;
}
export default PasswordForm;
//# sourceMappingURL=PasswordForm.d.ts.map